### Name: optparse-package
### Title: Command line option parser
### Aliases: optparse-package optparse
### Keywords: package

### ** Examples

    ## Not run: 
##D         #!/path/to/Rscript
##D         # specify our desired options in a list
##D         # by default ``OptionParser`` will automatically add an help option equivalent to 
##D         # ``make_option(c("-h", "--help"), action="store_true", default=FALSE, 
##D         #               help="Show this help message and exit")``
##D         option_list <- list( 
##D                 make_option(c("-v", "--verbose"), action="store_true", default=TRUE,
##D                     help="Print lots of output [default]"),
##D                 make_option(c("-q", "--quietly"), action="store_false", 
##D                     dest="verbose", help="Print little output"),
##D                 make_option(c("-c", "--count"), action="store", type="integer", default=10, 
##D                     help="Number of random normals to generate [default %default]"),
##D                 make_option(c("-m", "--mean"), action="store", type="numeric", default=0,
##D                     help="Mean of random normals [default %default]"),
##D                 make_option(c("-s", "--sd"), action="store", type="numeric", default=1,
##D                     help="Standard deviation of random normals [default %default]")
##D                 )
##D                                                 
##D         # get command line options, if not found set to specified defaults, 
##D         # and if help option encountered print help and exit
##D         opt <- parse_args(OptionParser(option_list))
##D 
##D         # print some progress messages to stderr if "quietly" wasn't requested
##D         if ( opt$verbose ) { write("writing...", stderr()) }
##D 
##D         # do some operations based on user input
##D         cat(paste(rnorm(opt$count, mean=opt$mean, sd=opt$sd), collapse="\n"))
##D         cat("\n")
##D     
## End(Not run)

    ## Don't show:
        if (require("RUnit")) {

            parser <- OptionParser( option_list = list( make_option(c("-q", "--quietly"), action="store_false", dest="verbose"),
                                                make_option("--verbose", action="store_true", dest="verbose", default=TRUE),
                                                make_option(c("-f", "--filename"), action="store", metavar="file")))
                                            
            # verbose should be false
            checkEquals(parse_args(parser, "-q"), list(verbose = FALSE, help = FALSE))
            checkException(checkEquals(parse_args(parser, "-q"), list(verbose = TRUE, help = FALSE)))
            print_help(parser)
        }
    ## End Don't show



